@@ -26,6 +26,10 @@
 #include <stdarg.h>
 #include <math.h>
 
+#if defined(HAVE_FORK) && HAVE_FORK==1
+#include <unistd.h>
+#endif /* HAVE_FORK */
+
 #include "check.h"
 #include "check_error.h"
 #include "check_list.h"
@@ -74,7 +78,6 @@ Suite *suite_create(const char *name)
 int suite_tcase(Suite * s, const char *tcname)
 {
     List *l;
-    TCase *tc;
 
     if(s == NULL)
         return 0;
@@ -82,7 +85,7 @@ int suite_tcase(Suite * s, const char *tcname)
     l = s->tclst;
     for(check_list_front(l); !check_list_at_end(l); check_list_advance(l))
     {
-        tc = (TCase *)check_list_val(l);
+        TCase *tc = (TCase *)check_list_val(l);
         if(strcmp(tcname, tc->name) == 0)
             return 1;
     }
@@ -171,15 +174,15 @@ List *tag_string_to_list(const char *tags_string)
 
     if (NULL == tags_string)
     {
-	return list;
+        return list;
     }
 
     tags = strdup(tags_string);
     tag = strtok(tags, " ");
     while (tag)
     {
-	check_list_add_end(list, strdup(tag));
-	tag = strtok(NULL, " ");
+        check_list_add_end(list, strdup(tag));
+        tag = strtok(NULL, " ");
     }
     free(tags);
     return list;
@@ -190,8 +193,8 @@ void tcase_set_tags(TCase * tc, const char *tags_orig)
     /* replace any pre-existing list */
     if (tc->tags)
     {
-	check_list_apply(tc->tags, free);
-	check_list_free(tc->tags);
+        check_list_apply(tc->tags, free);
+        check_list_free(tc->tags);
     }
     tc->tags = tag_string_to_list(tags_orig);
 }
@@ -218,21 +221,21 @@ unsigned int tcase_matching_tag(TCase *tc, List *check_for)
 
     if (NULL == check_for)
     {
-	return 0;
+        return 0;
     }
 
     for(check_list_front(check_for); !check_list_at_end(check_for);
         check_list_advance(check_for))
     {
-	for(check_list_front(tc->tags); !check_list_at_end(tc->tags);
-	    check_list_advance(tc->tags))
-	{
-	    if (0 == strcmp((const char *)check_list_val(tc->tags),
-			    (const char *)check_list_val(check_for)))
-	    {
-		return 1;
-	    }
-	}
+        for(check_list_front(tc->tags); !check_list_at_end(tc->tags);
+            check_list_advance(tc->tags))
+        {
+            if (0 == strcmp((const char *)check_list_val(tc->tags),
+                    (const char *)check_list_val(check_for)))
+            {
+            return 1;
+            }
+        }
     }
     return 0;
 }
@@ -247,21 +250,21 @@ void suite_add_tcase(Suite * s, TCase * tc)
     check_list_add_end(s->tclst, tc);
 }
 
-void _tcase_add_test(TCase * tc, TFun fn, const char *name, int _signal,
-                     int allowed_exit_value, int start, int end)
+void _tcase_add_test(TCase * tc, const TTest * ttest,
+                     int _signal, int allowed_exit_value,
+                     int start, int end)
 {
     TF *tf;
 
-    if(tc == NULL || fn == NULL || name == NULL)
+    if(tc == NULL || ttest == NULL)
         return;
     tf = (TF *)emalloc(sizeof(TF));   /* freed in tcase_free */
-    tf->fn = fn;
+    tf->ttest = ttest;
     tf->loop_start = start;
     tf->loop_end = end;
     tf->signal = _signal;       /* 0 means no signal expected */
     tf->allowed_exit_value =
       (WEXITSTATUS_MASK & allowed_exit_value);   /* 0 is default successful exit */
-    tf->name = name;
     check_list_add_end(tc->tflst, tf);
 }
 
@@ -349,9 +352,9 @@ void tcase_fn_start(const char *fname, const char *file,
     current_test_name = fname;
 }
 
-const char* tcase_name()
+const char* tcase_name(void)
 {
-	return current_test_name;
+    return current_test_name;
 }
 
 void _mark_point(const char *file, int line)
@@ -438,7 +441,6 @@ void srunner_add_suite(SRunner * sr, Suite * s)
 void srunner_free(SRunner * sr)
 {
     List *l;
-    TestResult *tr;
 
     if(sr == NULL)
         return;
@@ -454,7 +456,7 @@ void srunner_free(SRunner * sr)
     l = sr->resultlst;
     for(check_list_front(l); !check_list_at_end(l); check_list_advance(l))
     {
-        tr = (TestResult *)check_list_val(l);
+        TestResult *tr = (TestResult *)check_list_val(l);
         tr_free(tr);
     }
     check_list_free(sr->resultlst);
@@ -601,8 +603,6 @@ clockid_t check_get_clockid()
 {
     static clockid_t clockid = -1;
 
-    if(clockid == -1)
-    {
 /*
  * Only check if we have librt available. Otherwise, the clockid
  * will be ignored anyway, as the clock_gettime() and
@@ -611,21 +611,20 @@ clockid_t check_get_clockid()
  * will result in an assert(0).
  */
 #ifdef HAVE_LIBRT
-        timer_t timerid;
+    timer_t timerid;
 
-        if(timer_create(CLOCK_MONOTONIC, NULL, &timerid) == 0)
-        {
-            timer_delete(timerid);
-            clockid = CLOCK_MONOTONIC;
-        }
-        else
-        {
-            clockid = CLOCK_REALTIME;
-        }
-#else
+    if(timer_create(CLOCK_MONOTONIC, NULL, &timerid) == 0)
+    {
+        timer_delete(timerid);
         clockid = CLOCK_MONOTONIC;
-#endif
     }
+    else
+    {
+        clockid = CLOCK_REALTIME;
+    }
+#else
+    clockid = CLOCK_MONOTONIC;
+#endif
 
     return clockid;
 }
