@@ -90,8 +90,7 @@ int check_list_at_end(List * lp)
 {
     if(lp->current == -1)
         return 1;
-    else
-        return (lp->current > lp->last);
+    return (lp->current > lp->last);
 }
 
 void check_list_front(List * lp)
@@ -141,15 +140,15 @@ void check_list_apply(List * lp, void (*fp) (void *))
 
 }
 
-bool check_list_contains(List * lp, void *val)
+int check_list_contains(List * lp, void *val)
 {
     for(check_list_front(lp); !check_list_at_end(lp); check_list_advance(lp))
     {
         if(check_list_val(lp) == val)
         {
-            return true;
+            return 1;
         }
     }
 
-    return false;
+    return 0;
 }
