@@ -23,6 +23,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
+#include <stddef.h>
 
 #include "check.h"
 #include "check_error.h"
@@ -61,7 +62,7 @@ static size_t get_max_msg_size(void)
     size_t value = 0;
     char *env = getenv("CK_MAX_MSG_SIZE");
     if (env)
-        value = (size_t)strtoul(env, NULL, 10); // Cast in case size_t != unsigned long.
+        value = (size_t)strtoul(env, NULL, 10); /* Cast in case size_t != unsigned long. */
     if (value == 0)
         value = ck_max_msg_size;
     if (value == 0)
@@ -319,8 +320,7 @@ static void ppack_cleanup(void *mutex)
 void ppack(FILE * fdes, enum ck_msg_type type, CheckMsg * msg)
 {
     char *buf = NULL;
-    int n;
-    ssize_t r;
+    size_t n, r;
 
     n = pack(type, &buf, msg);
     /* Keep it on the safe side to not send too much data. */
@@ -468,7 +468,7 @@ static void rcvmsg_update_loc(RcvMsg * rmsg, const char *file, int line)
 
 RcvMsg *punpack(FILE * fdes)
 {
-    int nread, nparse, n;
+    int nread, nparse;
     char *buf;
     RcvMsg *rmsg;
 
@@ -483,7 +483,7 @@ RcvMsg *punpack(FILE * fdes)
     while(nparse > 0)
     {
         /* Parse one message */
-        n = get_result(buf, rmsg);
+        int n = get_result(buf, rmsg);
         nparse -= n;
         if (nparse < 0)
             eprintf("Error in call to get_result", __FILE__, __LINE__ - 3);
